==> pyskool-0.2.2.tar.bz2: pyskool-0.2.2/pyskool/stinkbomb.py <==
# -*- coding: utf-8 -*-
# Copyright 2010 Richard Dymond (rjdymond@gmail.com)
#
# This file is part of Pyskool.
#
# Pyskool is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# Pyskool is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# Pyskool. If not, see <http://www.gnu.org/licenses/>.

from character import Character
from animatorystates import *
from location import Location

class Stinkbomb(Character):
    def __init__(self, stinkbomb_id, tap_id):
        Character.__init__(self, stinkbomb_id, stinkbomb_id)
        self.tap_id = tap_id
        self.animatory_state = self.initial_as = STINKBOMB
        self.initial_direction = -1
        self.initial_location = Location((-3, 0))
        self.smelt = False

    def get_tap_id(self, lesson_id):
        return self.tap_id

    def drop(self, x, y):
        self.smelt = False
        self.x = x
        self.y = y

    def move_cloud(self):
        self.direction *= -1
        if not self.smelt:
            smeller = self.cast.smeller(self)
            if smeller:
                window = self.skool.nearby_window(smeller)
                if window and window.shut:
                    self.smelt = True
                    smeller.open_window(window)

==> pyskool-0.2.3.tar.bz2: pyskool-0.2.3/pyskool/stinkbomb.py <==
# -*- coding: utf-8 -*-
# Copyright 2010 Richard Dymond (rjdymond@gmail.com)
#
# This file is part of Pyskool.
#
# Pyskool is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# Pyskool is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# Pyskool. If not, see <http://www.gnu.org/licenses/>.

from character import Character
from animatorystates import *
from location import Location

# Phases of animation of a stinkbomb
PHASES = ((STINKBOMB, -1), (STINKBOMB, 1))

class Stinkbomb(Character):
    def __init__(self, stinkbomb_id, tap_id):
        Character.__init__(self, stinkbomb_id, stinkbomb_id)
        self.tap_id = tap_id
        self.animatory_state = self.initial_as = PHASES[0][0]
        self.initial_direction = PHASES[0][1]
        self.initial_location = Location((-3, 0))
        self.smelt = False
        self.phase_index = 0

    def get_tap_id(self, lesson_id):
        return self.tap_id

    def drop(self, x, y):
        self.smelt = False
        self.x = x
        self.y = y

    def move_cloud(self):
        self.phase_index = (self.phase_index + 1) % len(PHASES)
        self.animatory_states, self.direction = PHASES[self.phase_index]
        if not self.smelt:
            smeller = self.cast.smeller(self)
            if smeller:
                window = self.skool.nearby_window(smeller)
                if window and window.shut:
                    self.smelt = True
                    smeller.open_window(window)
